@@ -17,13 +17,15 @@
 #' @keywords bls api economics cpi unemployment inflation
 #' @export qcew_api
 #' @seealso \url{https://data.bls.gov/cew/doc/access/csv_data_slices.htm}
+#' @return A tibble from the BLS API.
 #' @examples
 #' 
+#'  \dontrun{
 #' # A request for the employment levels and wages for NIACS 5112: Software Publishers.
-#' dat <- qcew_api(year=2017, qtr="a", slice="industry", sliceCode=5112)
+#' dat <- qcew_api(c(format(Sys.Date(), "%Y")), qtr="1", slice="industry", sliceCode=10)
+#' }
 #' 
-#' 
-qcew_api <- function(year=2018, qtr="a", slice=NULL, sliceCode=NULL, ...){
+qcew_api <- function(year=c(format(Sys.Date(), "%Y")), qtr="1", slice=NULL, sliceCode=NULL, ...){
     if (is.null("slice") | is.null("sliceCode")){
         message("Please specify a Slice and sliceCode. See function documentation for examples.")
     }
